local LMP = LibStub("LibMediaProvider-1.0")
local isLoaded = false

local function GetCustomFontList()
	local fontArtList = 
	{	
		["Calligraphica"]			= "AUI/fonts/Kingthings_Calligraphica_2.ttf",
		["Almendra"]				= "AUI/fonts/Almendra-Bold.otf",
		["Sansita One"]				= "AUI/fonts/SansitaOne.ttf",
	    ["Bellota"]					= "AUI/fonts/Bellota-Bold.otf"
	}	
	
	return fontArtList
end

function AUI.RegisterMedia()
	for fontName, fontPath in pairs(GetCustomFontList()) do
		LMP:Register(LMP.MediaType.FONT, fontName, fontPath)
	end
end

local function AUI_OnFastUpdate()
	if AUI.Minimap.IsEnabled() then
		AUI.Minimap.Map.Update()
	end	
end

local function AUI_OnSlowUpdate()
	if AUI.Minimap.IsEnabled() then
		if AUI.Settings.Minimap.preview_locationName then
			AUI.Minimap.UI.UpdateLocationName()
			AUI.Minimap.Pin.UpdateMovingPins()
		end	
		
		if AUI.Settings.Minimap.preview_coords then
			 AUI.Minimap.UI.UpdateCoords()
		end
	end	
end

local function AUI_OnActivate(p_eventCode)
	AUI.Minimap.Show()
end

local function AUI_Push(eventCode, layerIndex, activeLayerIndex)
	if layerIndex ~= 7 then AUI.Minimap.Hide() end
end

local function AUI_Pop(eventCode, layerIndex, activeLayerIndex)
	if layerIndex ~= 5 and layerIndex ~= 20 then AUI.Minimap.Show() end
end

local function AUI_OnLoad(p_eventCode, p_addOnName)
	if p_addOnName ~= "AUI" or isLoaded then
        return
    end	
	
	AUI.RegisterMedia()
	AUI.MainMenu.SetMenuData()	
	AUI.LoadTemplateSettings()

	if AUI.ReloadUIHelper.IsEnabled() then
		AUI.ReloadUIHelper.Load()
	end	
	
	if AUI.Minimap.IsEnabled() then
		AUI.Minimap.Load()
	end		
	
	if AUI.Attributes.IsEnabled() then
		AUI.Attributes.Load()
	end

	if AUI.Combat.IsEnabled() then
		AUI.Combat.Load()	
	end
	
	if AUI.Actionbar.IsEnabled() then
		AUI.Actionbar.Load()
	end
	
	if AUI.Buffs.IsEnabled() then
		AUI.Buffs.Load()
	end	
	
	AUI.Keybinding.Create()	

	AUI_OnFastUpdate()
	AUI_OnSlowUpdate()
	
	EVENT_MANAGER:RegisterForUpdate("AUI_OnFastUpdate", 10, AUI_OnFastUpdate)
	EVENT_MANAGER:RegisterForUpdate("AUI_OnSlowUpdate", 400, AUI_OnSlowUpdate)
	
	EVENT_MANAGER:RegisterForEvent("AUI_Minimap_Show", EVENT_ACTION_LAYER_POPPED, AUI_Pop)
	EVENT_MANAGER:RegisterForEvent("AUI_Minimap_Hide", EVENT_ACTION_LAYER_PUSHED, AUI_Push)
	
	EVENT_MANAGER:UnregisterForEvent("AUI_EVENT_ADD_ON_LOADED", EVENT_ADD_ON_LOADED)
	
	AUI.LoadEvents()
	
	isLoaded = true
end

function AUI.Minimap.IsEnabled()
	return AUI.MainSettings.modul_minimap_enabled
end

function AUI.Attributes.IsEnabled()
	return AUI.MainSettings.modul_attribute_enabled
end

function AUI.Combat.IsEnabled()
	return AUI.MainSettings.modul_combat_stats_enabled
end

function AUI.Actionbar.IsEnabled()
	return AUI.MainSettings.modul_actionBar_enabled
end

function AUI.Buffs.IsEnabled()
	return AUI.MainSettings.modul_buffs_enabled
end

function AUI.ReloadUIHelper.IsEnabled()
	return true
end

EVENT_MANAGER:RegisterForEvent("AUI_EVENT_ADD_ON_LOADED", EVENT_ADD_ON_LOADED, AUI_OnLoad)
EVENT_MANAGER:RegisterForEvent("AUI_EVENT_PLAYER_ACTIVATED", EVENT_PLAYER_ACTIVATED, AUI_OnActivate)
